==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebPanePinnedEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebPanePinnedEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPanePinnedEventArgsDetailDescription, _super);
    function WebPanePinnedEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.h = null;
        _this.f = null;
        _this.k = false;
        _this.n = null;
        return _this;
    }
    WebPanePinnedEventArgsDetailDescription.prototype.get_type = function () {
        return "WebPanePinnedEventArgsDetail";
    };
    Object.defineProperty(WebPanePinnedEventArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPanePinnedEventArgsDetailDescription.prototype, "sourcePane", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("SourcePane");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPanePinnedEventArgsDetailDescription.prototype, "panes", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Panes");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPanePinnedEventArgsDetailDescription.prototype, "newValue", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.e("NewValue");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPanePinnedEventArgsDetailDescription.prototype, "location", {
        get: function () {
            return this.n;
        },
        set: function (a) {
            this.n = a;
            this.e("Location");
        },
        enumerable: true,
        configurable: true
    });
    WebPanePinnedEventArgsDetailDescription.$t = markType(WebPanePinnedEventArgsDetailDescription, 'WebPanePinnedEventArgsDetailDescription', Description.$);
    WebPanePinnedEventArgsDetailDescription.__marshalByValue = true;
    WebPanePinnedEventArgsDetailDescription.__marshalByValueAlias = "PanePinnedEventArgsDetail";
    return WebPanePinnedEventArgsDetailDescription;
}(Description));
export { WebPanePinnedEventArgsDetailDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebPanePinnedEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebPanePinnedEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPanePinnedEventArgsDetailDescription, _super);
    function WebPanePinnedEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.j = null;
        _this.h = null;
        _this.m = false;
        _this.p = null;
        return _this;
    }
    WebPanePinnedEventArgsDetailDescription.prototype.get_type = function () {
        return "WebPanePinnedEventArgsDetail";
    };
    Object.defineProperty(WebPanePinnedEventArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPanePinnedEventArgsDetailDescription.prototype, "sourcePane", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("SourcePane");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPanePinnedEventArgsDetailDescription.prototype, "panes", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Panes");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPanePinnedEventArgsDetailDescription.prototype, "newValue", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.g("NewValue");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPanePinnedEventArgsDetailDescription.prototype, "location", {
        get: function () {
            return this.p;
        },
        set: function (a) {
            this.p = a;
            this.g("Location");
        },
        enumerable: false,
        configurable: true
    });
    WebPanePinnedEventArgsDetailDescription.$t = markType(WebPanePinnedEventArgsDetailDescription, 'WebPanePinnedEventArgsDetailDescription', Description.$);
    WebPanePinnedEventArgsDetailDescription.__marshalByValue = true;
    WebPanePinnedEventArgsDetailDescription.__marshalByValueAlias = "PanePinnedEventArgsDetail";
    return WebPanePinnedEventArgsDetailDescription;
}(Description));
export { WebPanePinnedEventArgsDetailDescription };
